@@ -1,17 +1,17 @@
-from typing import Optional, List, Union, Tuple
+from pathlib import Path
+from typing import List, Optional, Tuple
 
 import numpy as np
+from docarray import Document, DocumentArray
 from loguru import logger
-from pathlib import Path
 
-from jina import DocumentArray, Document
+from .core.codec.pq import PQCodec
+from .core.index.hnsw import HnswIndex
+from .core.index.pq_index import PQIndex
+from .enums import Metric
 from .storage.base import ExpandMode
 from .storage.kv import DocStorage
 from .storage.table import CellTable, MetaTable
-from .core.index.pq_index import PQIndex
-from .core.index.hnsw import HnswIndex
-from .enums import Metric
-from .core.codec.pq import PQCodec
 
 
 class CellContainer:
@@ -26,6 +26,7 @@ class CellContainer:
         expand_mode: ExpandMode = ExpandMode.STEP,
         columns: Optional[List[tuple]] = None,
         data_path: Path = Path('./data'),
+        **kwargs,
     ):
         self.dim = dim
         self.metric = metric
@@ -41,6 +42,7 @@ class CellContainer:
                     initial_size=initial_size,
                     expand_step_size=expand_step_size,
                     expand_mode=expand_mode,
+                    **kwargs,
                 )
                 for _ in range(n_cells)
             ]
@@ -52,6 +54,7 @@ class CellContainer:
                     initial_size=initial_size,
                     expand_step_size=expand_step_size,
                     expand_mode=expand_mode,
+                    **kwargs,
                 )
                 for _ in range(n_cells)
             ]
@@ -145,7 +148,6 @@ class CellContainer:
             )
 
             topk_dists.append(dists)
-
             match_docs = DocumentArray()
             for dist, doc_id, cell_id in zip(dists, doc_ids, cells):
                 doc = Document(id=doc_id)
@@ -158,6 +160,28 @@ class CellContainer:
 
         return topk_dists, topk_docs
 
+    def _search_cells(
+        self,
+        query: np.ndarray,
+        cells: np.ndarray,
+        where_clause: str = '',
+        where_params: Tuple = (),
+        limit: int = 10,
+    ):
+        topk_dists, topk_ids = [], []
+        for x, cell_idx in zip(query, cells):
+            dists, ids, cells = self.ivf_search(
+                x,
+                cells=cell_idx,
+                where_clause=where_clause,
+                where_params=where_params,
+                limit=limit,
+            )
+            topk_dists.append(dists)
+            topk_ids.append(ids)
+
+        return topk_dists, [np.array(ids, dtype=int) for ids in topk_ids]
+
     def insert(
         self,
         data: np.ndarray,
