@@ -1,5 +1,5 @@
 import abc
-from typing import Optional, List, Union
+from typing import List, Optional, Union
 
 import numpy as np
 
