@@ -1,14 +1,15 @@
-from typing import Optional, List, Union, Dict
 import hashlib
 from pathlib import Path
+from typing import Dict, List, Optional, Union
+
 import numpy as np
+from docarray import DocumentArray
+from docarray.math.distance import cdist
+from docarray.math.helper import top_k
 from loguru import logger
 
-from jina import DocumentArray
-from jina.math.distance import cdist
-from jina.math.helper import top_k
-from .core import VQCodec, PQCodec
 from .container import CellContainer
+from .core import PQCodec, VQCodec
 from .enums import Metric
 from .filter import Filter
 
@@ -110,6 +111,7 @@ class PQLite(CellContainer):
             expand_step_size=expand_step_size,
             columns=columns,
             data_path=data_path,
+            **kwargs,
         )
 
         if self.total_docs > 0:
@@ -201,7 +203,7 @@ class PQLite(CellContainer):
         docs: DocumentArray,
         filter: Dict = {},
         limit: int = 10,
-        include_metadata: bool = False,
+        include_metadata: bool = True,
         **kwargs,
     ):
         """Search the index, and attach matches to the query Documents in `docs`
@@ -211,15 +213,45 @@ class PQLite(CellContainer):
         :param limit: the number of results to get for each query document in search
         :param include_metadata: whether to return document metadata in response.
         """
-        query = docs.embeddings
-        n_data, _ = self._sanity_check(query)
+        query_np = docs.embeddings
 
+        match_dists, match_docs = self._search_documents(
+            query_np, filter, limit, include_metadata
+        )
+
+        for doc, matches in zip(docs, match_docs):
+            doc.matches = matches
+
+    def _search_documents(
+        self,
+        query_np,
+        filter: Dict = {},
+        limit: int = 10,
+        include_metadata: bool = True,
+    ):
+
+        cells = self._cell_selection(query_np, limit)
+        where_clause, where_params = Filter(filter).parse_where_clause()
+
+        match_dists, match_docs = self.search_cells(
+            query=query_np,
+            cells=cells,
+            where_clause=where_clause,
+            where_params=where_params,
+            limit=limit,
+            include_metadata=include_metadata,
+        )
+        return match_dists, match_docs
+
+    def _cell_selection(self, query_np, limit):
+
+        n_data, _ = self._sanity_check(query_np)
         assert 0 < limit <= 1024
 
         if self.vq_codec:
-            vq_codebook = self.vq_codec.codebook
-            # find n_probe closest cells
-            dists = cdist(query, vq_codebook, metric=self.metric.name.lower())
+            dists = cdist(
+                query_np, self.vq_codec.codebook, metric=self.metric.name.lower()
+            )
             dists, cells = top_k(dists, k=self.n_probe)
         else:
             cells = np.zeros((n_data, 1), dtype=np.int64)
@@ -238,21 +270,46 @@ class PQLite(CellContainer):
         #     n_probe_list = torch.ceil(normalized_entropy * max_n_probe).long()
         # else:
         #     n_probe_list = None
-        #
 
+        return cells
+
+    def search_numpy(
+        self,
+        query_np: np.ndarray,
+        filter: Dict = {},
+        limit: int = 10,
+        include_metadata: bool = True,
+        **kwargs,
+    ):
+        """Search the index and return distances to the query and ids of the closest documents.
+
+        :param query_np: matrix containing query vectors as rows
+        :param filter: the filtering conditions
+        :param limit: the number of results to get for each query document in search
+        :param include_metadata: whether to return document metadata in response.
+        """
+
+        dists, doc_ids = self._search_numpy(query_np, filter, limit)
+        return dists, doc_ids
+
+    def _search_numpy(self, query_np, filter: Dict = {}, limit: int = 10):
+        """Search approximate nearest vectors in different cells, returns distances and ids
+
+        :param query_np: matrix containing query vectors as rows
+        :param filter: the filtering conditions
+        :param limit: the number of results to get for each query document in search
+        """
+        cells = self._cell_selection(query_np, limit)
         where_clause, where_params = Filter(filter).parse_where_clause()
 
-        match_dists, match_docs = self.search_cells(
-            query=query,
+        dists, ids = self._search_cells(
+            query=query_np,
             cells=cells,
             where_clause=where_clause,
             where_params=where_params,
             limit=limit,
-            include_metadata=include_metadata,
         )
-
-        for doc, matches in zip(docs, match_docs):
-            doc.matches = matches
+        return dists, ids
 
     def delete(self, docs: Union[DocumentArray, List[str]]):
         """Delete entries from the index by id
