@@ -1,5 +1,5 @@
 import abc
-from typing import Optional, List
+from typing import List, Optional
 
 import numpy as np
 
